@@ -15,6 +15,7 @@ from pygments.styles.default import DefaultStyle
 from prompt_toolkit.application import AbortAction
 from prompt_toolkit.enums import DEFAULT_BUFFER
 from prompt_toolkit.interface import AcceptAction
+from prompt_toolkit.key_binding.vi_state import InputMode
 from prompt_toolkit.layout.utils import token_list_width
 from prompt_toolkit.shortcuts import create_asyncio_eventloop
 from prompt_toolkit.styles import style_from_pygments
@@ -85,7 +86,11 @@ class PythonRepl(PythonInput):
             # Append to history and reset.
             cli.search_state.text = ''
             cli.buffers[DEFAULT_BUFFER].reset(append_to_history=True)
-            self.key_bindings_manager.reset(cli)
+
+        # Make sure that we end up in insert mode.
+        # (Not exactly the right place to check this.)
+        if cli.vi_state.input_mode == InputMode.NAVIGATION:
+            cli.vi_state.input_mode = InputMode.INSERT
 
     def _execute(self, cli, line):
         """
@@ -159,6 +164,12 @@ class PythonRepl(PythonInput):
         if l:
             l.insert(0, "Traceback (most recent call last):\n")
         l.extend(traceback.format_exception_only(t, v))
+
+        # For Python2: `format_list` and `format_exception_only` return
+        # non-unicode strings. Ensure that everything is unicode.
+        if six.PY2:
+            l = [i.decode('utf-8') if isinstance(i, six.binary_type) else i for i in l]
+
         tb = ''.join(l)
 
         # Format exception and write to output.
